==========
roboticspy
==========

.. image:: https://img.shields.io/travis/davidcmccoll/roboticspy.svg
        :target: https://travis-ci.org/davidcmccoll/roboticspy

.. image:: https://img.shields.io/pypi/v/roboticspy.svg
        :target: https://pypi.python.org/pypi/roboticspy


Python package for doing science.

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://davidcmccoll.github.io/roboticspy.

Features
--------

* TODO
